"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.capability.v1beta1.capability_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisOwners(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    INDEX_OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    @property
    def index_owners(self) -> cosmos.capability.v1beta1.capability_pb2.CapabilityOwners: ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        index_owners : typing.Optional[cosmos.capability.v1beta1.capability_pb2.CapabilityOwners] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"index_owners",b"index_owners"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"index_owners",b"index_owners"]) -> None: ...
global___GenesisOwners = GenesisOwners

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    OWNERS_FIELD_NUMBER: builtins.int
    index: builtins.int = ...

    @property
    def owners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisOwners]: ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        owners : typing.Optional[typing.Iterable[global___GenesisOwners]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"owners",b"owners"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MultiSignature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURES_FIELD_NUMBER: builtins.int

    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        signatures : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signatures",b"signatures"]) -> None: ...
global___MultiSignature = MultiSignature

class CompactBitArray(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTRA_BITS_STORED_FIELD_NUMBER: builtins.int
    ELEMS_FIELD_NUMBER: builtins.int
    extra_bits_stored: builtins.int = ...
    elems: builtins.bytes = ...

    def __init__(self,
        *,
        extra_bits_stored : builtins.int = ...,
        elems : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"elems",b"elems",u"extra_bits_stored",b"extra_bits_stored"]) -> None: ...
global___CompactBitArray = CompactBitArray



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENTS_FIELD_NUMBER: builtins.int
    CLIENTS_CONSENSUS_FIELD_NUMBER: builtins.int
    CLIENTS_METADATA_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    CREATE_LOCALHOST_FIELD_NUMBER: builtins.int
    NEXT_CLIENT_SEQUENCE_FIELD_NUMBER: builtins.int
    create_localhost: builtins.bool = ...
    next_client_sequence: builtins.int = ...

    @property
    def clients(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.client.v1.client_pb2.IdentifiedClientState]: ...

    @property
    def clients_consensus(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.client.v1.client_pb2.ClientConsensusStates]: ...

    @property
    def clients_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentifiedGenesisMetadata]: ...

    @property
    def params(self) -> ibc.core.client.v1.client_pb2.Params: ...

    def __init__(self,
        *,
        clients : typing.Optional[typing.Iterable[ibc.core.client.v1.client_pb2.IdentifiedClientState]] = ...,
        clients_consensus : typing.Optional[typing.Iterable[ibc.core.client.v1.client_pb2.ClientConsensusStates]] = ...,
        clients_metadata : typing.Optional[typing.Iterable[global___IdentifiedGenesisMetadata]] = ...,
        params : typing.Optional[ibc.core.client.v1.client_pb2.Params] = ...,
        create_localhost : builtins.bool = ...,
        next_client_sequence : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"clients",b"clients",u"clients_consensus",b"clients_consensus",u"clients_metadata",b"clients_metadata",u"create_localhost",b"create_localhost",u"next_client_sequence",b"next_client_sequence",u"params",b"params"]) -> None: ...
global___GenesisState = GenesisState

class GenesisMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...
global___GenesisMetadata = GenesisMetadata

class IdentifiedGenesisMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_METADATA_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def client_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenesisMetadata]: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        client_metadata : typing.Optional[typing.Iterable[global___GenesisMetadata]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_metadata",b"client_metadata"]) -> None: ...
global___IdentifiedGenesisMetadata = IdentifiedGenesisMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import tendermint.abci.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TxResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    TXHASH_FIELD_NUMBER: builtins.int
    CODESPACE_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    RAW_LOG_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    TX_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    txhash: typing.Text = ...
    codespace: typing.Text = ...
    code: builtins.int = ...
    data: typing.Text = ...
    raw_log: typing.Text = ...
    info: typing.Text = ...
    gas_wanted: builtins.int = ...
    gas_used: builtins.int = ...
    timestamp: typing.Text = ...

    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ABCIMessageLog]: ...

    @property
    def tx(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        txhash : typing.Text = ...,
        codespace : typing.Text = ...,
        code : builtins.int = ...,
        data : typing.Text = ...,
        raw_log : typing.Text = ...,
        logs : typing.Optional[typing.Iterable[global___ABCIMessageLog]] = ...,
        info : typing.Text = ...,
        gas_wanted : builtins.int = ...,
        gas_used : builtins.int = ...,
        tx : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        timestamp : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"tx",b"tx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"codespace",b"codespace",u"data",b"data",u"gas_used",b"gas_used",u"gas_wanted",b"gas_wanted",u"height",b"height",u"info",b"info",u"logs",b"logs",u"raw_log",b"raw_log",u"timestamp",b"timestamp",u"tx",b"tx",u"txhash",b"txhash"]) -> None: ...
global___TxResponse = TxResponse

class ABCIMessageLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSG_INDEX_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    msg_index: builtins.int = ...
    log: typing.Text = ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StringEvent]: ...

    def __init__(self,
        *,
        msg_index : builtins.int = ...,
        log : typing.Text = ...,
        events : typing.Optional[typing.Iterable[global___StringEvent]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"events",b"events",u"log",b"log",u"msg_index",b"msg_index"]) -> None: ...
global___ABCIMessageLog = ABCIMessageLog

class StringEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    type: typing.Text = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Attribute]: ...

    def __init__(self,
        *,
        type : typing.Text = ...,
        attributes : typing.Optional[typing.Iterable[global___Attribute]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"type",b"type"]) -> None: ...
global___StringEvent = StringEvent

class Attribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    value: typing.Text = ...

    def __init__(self,
        *,
        key : typing.Text = ...,
        value : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...
global___Attribute = Attribute

class GasInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    gas_wanted: builtins.int = ...
    gas_used: builtins.int = ...

    def __init__(self,
        *,
        gas_wanted : builtins.int = ...,
        gas_used : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"gas_used",b"gas_used",u"gas_wanted",b"gas_wanted"]) -> None: ...
global___GasInfo = GasInfo

class Result(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    log: typing.Text = ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[tendermint.abci.types_pb2.Event]: ...

    def __init__(self,
        *,
        data : builtins.bytes = ...,
        log : typing.Text = ...,
        events : typing.Optional[typing.Iterable[tendermint.abci.types_pb2.Event]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"events",b"events",u"log",b"log"]) -> None: ...
global___Result = Result

class SimulationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GAS_INFO_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int

    @property
    def gas_info(self) -> global___GasInfo: ...

    @property
    def result(self) -> global___Result: ...

    def __init__(self,
        *,
        gas_info : typing.Optional[global___GasInfo] = ...,
        result : typing.Optional[global___Result] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"gas_info",b"gas_info",u"result",b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"gas_info",b"gas_info",u"result",b"result"]) -> None: ...
global___SimulationResponse = SimulationResponse

class MsgData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MSG_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    msg_type: typing.Text = ...
    data: builtins.bytes = ...

    def __init__(self,
        *,
        msg_type : typing.Text = ...,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"msg_type",b"msg_type"]) -> None: ...
global___MsgData = MsgData

class TxMsgData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int

    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MsgData]: ...

    def __init__(self,
        *,
        data : typing.Optional[typing.Iterable[global___MsgData]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___TxMsgData = TxMsgData

class SearchTxsResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_COUNT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    PAGE_TOTAL_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    TXS_FIELD_NUMBER: builtins.int
    total_count: builtins.int = ...
    count: builtins.int = ...
    page_number: builtins.int = ...
    page_total: builtins.int = ...
    limit: builtins.int = ...

    @property
    def txs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TxResponse]: ...

    def __init__(self,
        *,
        total_count : builtins.int = ...,
        count : builtins.int = ...,
        page_number : builtins.int = ...,
        page_total : builtins.int = ...,
        limit : builtins.int = ...,
        txs : typing.Optional[typing.Iterable[global___TxResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"count",b"count",u"limit",b"limit",u"page_number",b"page_number",u"page_total",b"page_total",u"total_count",b"total_count",u"txs",b"txs"]) -> None: ...
global___SearchTxsResult = SearchTxsResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import confio.proofs_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MerkleRoot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    hash: builtins.bytes = ...

    def __init__(self,
        *,
        hash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash"]) -> None: ...
global___MerkleRoot = MerkleRoot

class MerklePrefix(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_PREFIX_FIELD_NUMBER: builtins.int
    key_prefix: builtins.bytes = ...

    def __init__(self,
        *,
        key_prefix : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key_prefix",b"key_prefix"]) -> None: ...
global___MerklePrefix = MerklePrefix

class MerklePath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_PATH_FIELD_NUMBER: builtins.int

    @property
    def key_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        key_path : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key_path",b"key_path"]) -> None: ...
global___MerklePath = MerklePath

class MerkleProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROOFS_FIELD_NUMBER: builtins.int

    @property
    def proofs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[confio.proofs_pb2.CommitmentProof]: ...

    def __init__(self,
        *,
        proofs : typing.Optional[typing.Iterable[confio.proofs_pb2.CommitmentProof]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proofs",b"proofs"]) -> None: ...
global___MerkleProof = MerkleProof



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import tendermint.crypto.proof_pb2
import tendermint.types.validator_pb2
import tendermint.version.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BlockIDFlag(metaclass=_BlockIDFlag):
    V = typing.NewType('V', builtins.int)

global___BlockIDFlag = BlockIDFlag

BLOCK_ID_FLAG_UNKNOWN = BlockIDFlag.V(0)
BLOCK_ID_FLAG_ABSENT = BlockIDFlag.V(1)
BLOCK_ID_FLAG_COMMIT = BlockIDFlag.V(2)
BLOCK_ID_FLAG_NIL = BlockIDFlag.V(3)

class _BlockIDFlag(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BlockIDFlag.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    BLOCK_ID_FLAG_UNKNOWN = BlockIDFlag.V(0)
    BLOCK_ID_FLAG_ABSENT = BlockIDFlag.V(1)
    BLOCK_ID_FLAG_COMMIT = BlockIDFlag.V(2)
    BLOCK_ID_FLAG_NIL = BlockIDFlag.V(3)

class SignedMsgType(metaclass=_SignedMsgType):
    V = typing.NewType('V', builtins.int)

global___SignedMsgType = SignedMsgType

SIGNED_MSG_TYPE_UNKNOWN = SignedMsgType.V(0)
SIGNED_MSG_TYPE_PREVOTE = SignedMsgType.V(1)
SIGNED_MSG_TYPE_PRECOMMIT = SignedMsgType.V(2)
SIGNED_MSG_TYPE_PROPOSAL = SignedMsgType.V(32)

class _SignedMsgType(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SignedMsgType.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    SIGNED_MSG_TYPE_UNKNOWN = SignedMsgType.V(0)
    SIGNED_MSG_TYPE_PREVOTE = SignedMsgType.V(1)
    SIGNED_MSG_TYPE_PRECOMMIT = SignedMsgType.V(2)
    SIGNED_MSG_TYPE_PROPOSAL = SignedMsgType.V(32)

class PartSetHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    total: builtins.int = ...
    hash: builtins.bytes = ...

    def __init__(self,
        *,
        total : builtins.int = ...,
        hash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash",u"total",b"total"]) -> None: ...
global___PartSetHeader = PartSetHeader

class Part(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    BYTES_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    index: builtins.int = ...
    bytes: builtins.bytes = ...

    @property
    def proof(self) -> tendermint.crypto.proof_pb2.Proof: ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        bytes : builtins.bytes = ...,
        proof : typing.Optional[tendermint.crypto.proof_pb2.Proof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bytes",b"bytes",u"index",b"index",u"proof",b"proof"]) -> None: ...
global___Part = Part

class BlockID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    PART_SET_HEADER_FIELD_NUMBER: builtins.int
    hash: builtins.bytes = ...

    @property
    def part_set_header(self) -> global___PartSetHeader: ...

    def __init__(self,
        *,
        hash : builtins.bytes = ...,
        part_set_header : typing.Optional[global___PartSetHeader] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"part_set_header",b"part_set_header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash",u"part_set_header",b"part_set_header"]) -> None: ...
global___BlockID = BlockID

class Header(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    LAST_BLOCK_ID_FIELD_NUMBER: builtins.int
    LAST_COMMIT_HASH_FIELD_NUMBER: builtins.int
    DATA_HASH_FIELD_NUMBER: builtins.int
    VALIDATORS_HASH_FIELD_NUMBER: builtins.int
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: builtins.int
    CONSENSUS_HASH_FIELD_NUMBER: builtins.int
    APP_HASH_FIELD_NUMBER: builtins.int
    LAST_RESULTS_HASH_FIELD_NUMBER: builtins.int
    EVIDENCE_HASH_FIELD_NUMBER: builtins.int
    PROPOSER_ADDRESS_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    height: builtins.int = ...
    last_commit_hash: builtins.bytes = ...
    data_hash: builtins.bytes = ...
    validators_hash: builtins.bytes = ...
    next_validators_hash: builtins.bytes = ...
    consensus_hash: builtins.bytes = ...
    app_hash: builtins.bytes = ...
    last_results_hash: builtins.bytes = ...
    evidence_hash: builtins.bytes = ...
    proposer_address: builtins.bytes = ...

    @property
    def version(self) -> tendermint.version.types_pb2.Consensus: ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def last_block_id(self) -> global___BlockID: ...

    def __init__(self,
        *,
        version : typing.Optional[tendermint.version.types_pb2.Consensus] = ...,
        chain_id : typing.Text = ...,
        height : builtins.int = ...,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        last_block_id : typing.Optional[global___BlockID] = ...,
        last_commit_hash : builtins.bytes = ...,
        data_hash : builtins.bytes = ...,
        validators_hash : builtins.bytes = ...,
        next_validators_hash : builtins.bytes = ...,
        consensus_hash : builtins.bytes = ...,
        app_hash : builtins.bytes = ...,
        last_results_hash : builtins.bytes = ...,
        evidence_hash : builtins.bytes = ...,
        proposer_address : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"last_block_id",b"last_block_id",u"time",b"time",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_hash",b"app_hash",u"chain_id",b"chain_id",u"consensus_hash",b"consensus_hash",u"data_hash",b"data_hash",u"evidence_hash",b"evidence_hash",u"height",b"height",u"last_block_id",b"last_block_id",u"last_commit_hash",b"last_commit_hash",u"last_results_hash",b"last_results_hash",u"next_validators_hash",b"next_validators_hash",u"proposer_address",b"proposer_address",u"time",b"time",u"validators_hash",b"validators_hash",u"version",b"version"]) -> None: ...
global___Header = Header

class Data(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TXS_FIELD_NUMBER: builtins.int

    @property
    def txs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        txs : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"txs",b"txs"]) -> None: ...
global___Data = Data

class Vote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_INDEX_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    type: global___SignedMsgType.V = ...
    height: builtins.int = ...
    round: builtins.int = ...
    validator_address: builtins.bytes = ...
    validator_index: builtins.int = ...
    signature: builtins.bytes = ...

    @property
    def block_id(self) -> global___BlockID: ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        type : global___SignedMsgType.V = ...,
        height : builtins.int = ...,
        round : builtins.int = ...,
        block_id : typing.Optional[global___BlockID] = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        validator_address : builtins.bytes = ...,
        validator_index : builtins.int = ...,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"height",b"height",u"round",b"round",u"signature",b"signature",u"timestamp",b"timestamp",u"type",b"type",u"validator_address",b"validator_address",u"validator_index",b"validator_index"]) -> None: ...
global___Vote = Vote

class Commit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    SIGNATURES_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    round: builtins.int = ...

    @property
    def block_id(self) -> global___BlockID: ...

    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommitSig]: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        round : builtins.int = ...,
        block_id : typing.Optional[global___BlockID] = ...,
        signatures : typing.Optional[typing.Iterable[global___CommitSig]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"height",b"height",u"round",b"round",u"signatures",b"signatures"]) -> None: ...
global___Commit = Commit

class CommitSig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_ID_FLAG_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    block_id_flag: global___BlockIDFlag.V = ...
    validator_address: builtins.bytes = ...
    signature: builtins.bytes = ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        block_id_flag : global___BlockIDFlag.V = ...,
        validator_address : builtins.bytes = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_id_flag",b"block_id_flag",u"signature",b"signature",u"timestamp",b"timestamp",u"validator_address",b"validator_address"]) -> None: ...
global___CommitSig = CommitSig

class Proposal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROUND_FIELD_NUMBER: builtins.int
    POL_ROUND_FIELD_NUMBER: builtins.int
    BLOCK_ID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    type: global___SignedMsgType.V = ...
    height: builtins.int = ...
    round: builtins.int = ...
    pol_round: builtins.int = ...
    signature: builtins.bytes = ...

    @property
    def block_id(self) -> global___BlockID: ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        type : global___SignedMsgType.V = ...,
        height : builtins.int = ...,
        round : builtins.int = ...,
        pol_round : builtins.int = ...,
        block_id : typing.Optional[global___BlockID] = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"height",b"height",u"pol_round",b"pol_round",u"round",b"round",u"signature",b"signature",u"timestamp",b"timestamp",u"type",b"type"]) -> None: ...
global___Proposal = Proposal

class SignedHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int

    @property
    def header(self) -> global___Header: ...

    @property
    def commit(self) -> global___Commit: ...

    def __init__(self,
        *,
        header : typing.Optional[global___Header] = ...,
        commit : typing.Optional[global___Commit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit",b"commit",u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit",b"commit",u"header",b"header"]) -> None: ...
global___SignedHeader = SignedHeader

class LightBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNED_HEADER_FIELD_NUMBER: builtins.int
    VALIDATOR_SET_FIELD_NUMBER: builtins.int

    @property
    def signed_header(self) -> global___SignedHeader: ...

    @property
    def validator_set(self) -> tendermint.types.validator_pb2.ValidatorSet: ...

    def __init__(self,
        *,
        signed_header : typing.Optional[global___SignedHeader] = ...,
        validator_set : typing.Optional[tendermint.types.validator_pb2.ValidatorSet] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"signed_header",b"signed_header",u"validator_set",b"validator_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signed_header",b"signed_header",u"validator_set",b"validator_set"]) -> None: ...
global___LightBlock = LightBlock

class BlockMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_SIZE_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    NUM_TXS_FIELD_NUMBER: builtins.int
    block_size: builtins.int = ...
    num_txs: builtins.int = ...

    @property
    def block_id(self) -> global___BlockID: ...

    @property
    def header(self) -> global___Header: ...

    def __init__(self,
        *,
        block_id : typing.Optional[global___BlockID] = ...,
        block_size : builtins.int = ...,
        header : typing.Optional[global___Header] = ...,
        num_txs : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_id",b"block_id",u"block_size",b"block_size",u"header",b"header",u"num_txs",b"num_txs"]) -> None: ...
global___BlockMeta = BlockMeta

class TxProof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROOT_HASH_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    root_hash: builtins.bytes = ...
    data: builtins.bytes = ...

    @property
    def proof(self) -> tendermint.crypto.proof_pb2.Proof: ...

    def __init__(self,
        *,
        root_hash : builtins.bytes = ...,
        data : builtins.bytes = ...,
        proof : typing.Optional[tendermint.crypto.proof_pb2.Proof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"proof",b"proof",u"root_hash",b"root_hash"]) -> None: ...
global___TxProof = TxProof



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import confio.proofs_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import ibc.core.client.v1.client_pb2
import ibc.core.commitment.v1.commitment_pb2
import tendermint.types.types_pb2
import tendermint.types.validator_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClientState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    TRUST_LEVEL_FIELD_NUMBER: builtins.int
    TRUSTING_PERIOD_FIELD_NUMBER: builtins.int
    UNBONDING_PERIOD_FIELD_NUMBER: builtins.int
    MAX_CLOCK_DRIFT_FIELD_NUMBER: builtins.int
    FROZEN_HEIGHT_FIELD_NUMBER: builtins.int
    LATEST_HEIGHT_FIELD_NUMBER: builtins.int
    PROOF_SPECS_FIELD_NUMBER: builtins.int
    UPGRADE_PATH_FIELD_NUMBER: builtins.int
    ALLOW_UPDATE_AFTER_EXPIRY_FIELD_NUMBER: builtins.int
    ALLOW_UPDATE_AFTER_MISBEHAVIOUR_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...

    @property
    def upgrade_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    allow_update_after_expiry: builtins.bool = ...
    allow_update_after_misbehaviour: builtins.bool = ...

    @property
    def trust_level(self) -> global___Fraction: ...

    @property
    def trusting_period(self) -> google.protobuf.duration_pb2.Duration: ...

    @property
    def unbonding_period(self) -> google.protobuf.duration_pb2.Duration: ...

    @property
    def max_clock_drift(self) -> google.protobuf.duration_pb2.Duration: ...

    @property
    def frozen_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    @property
    def latest_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    @property
    def proof_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[confio.proofs_pb2.ProofSpec]: ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        trust_level : typing.Optional[global___Fraction] = ...,
        trusting_period : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        unbonding_period : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        max_clock_drift : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        frozen_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        latest_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        proof_specs : typing.Optional[typing.Iterable[confio.proofs_pb2.ProofSpec]] = ...,
        upgrade_path : typing.Optional[typing.Iterable[typing.Text]] = ...,
        allow_update_after_expiry : builtins.bool = ...,
        allow_update_after_misbehaviour : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"frozen_height",b"frozen_height",u"latest_height",b"latest_height",u"max_clock_drift",b"max_clock_drift",u"trust_level",b"trust_level",u"trusting_period",b"trusting_period",u"unbonding_period",b"unbonding_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"allow_update_after_expiry",b"allow_update_after_expiry",u"allow_update_after_misbehaviour",b"allow_update_after_misbehaviour",u"chain_id",b"chain_id",u"frozen_height",b"frozen_height",u"latest_height",b"latest_height",u"max_clock_drift",b"max_clock_drift",u"proof_specs",b"proof_specs",u"trust_level",b"trust_level",u"trusting_period",b"trusting_period",u"unbonding_period",b"unbonding_period",u"upgrade_path",b"upgrade_path"]) -> None: ...
global___ClientState = ClientState

class ConsensusState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIMESTAMP_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    NEXT_VALIDATORS_HASH_FIELD_NUMBER: builtins.int
    next_validators_hash: builtins.bytes = ...

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def root(self) -> ibc.core.commitment.v1.commitment_pb2.MerkleRoot: ...

    def __init__(self,
        *,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        root : typing.Optional[ibc.core.commitment.v1.commitment_pb2.MerkleRoot] = ...,
        next_validators_hash : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"root",b"root",u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_validators_hash",b"next_validators_hash",u"root",b"root",u"timestamp",b"timestamp"]) -> None: ...
global___ConsensusState = ConsensusState

class Misbehaviour(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    HEADER_1_FIELD_NUMBER: builtins.int
    HEADER_2_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    @property
    def header_1(self) -> global___Header: ...

    @property
    def header_2(self) -> global___Header: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        header_1 : typing.Optional[global___Header] = ...,
        header_2 : typing.Optional[global___Header] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header_1",b"header_1",u"header_2",b"header_2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"header_1",b"header_1",u"header_2",b"header_2"]) -> None: ...
global___Misbehaviour = Misbehaviour

class Header(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNED_HEADER_FIELD_NUMBER: builtins.int
    VALIDATOR_SET_FIELD_NUMBER: builtins.int
    TRUSTED_HEIGHT_FIELD_NUMBER: builtins.int
    TRUSTED_VALIDATORS_FIELD_NUMBER: builtins.int

    @property
    def signed_header(self) -> tendermint.types.types_pb2.SignedHeader: ...

    @property
    def validator_set(self) -> tendermint.types.validator_pb2.ValidatorSet: ...

    @property
    def trusted_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    @property
    def trusted_validators(self) -> tendermint.types.validator_pb2.ValidatorSet: ...

    def __init__(self,
        *,
        signed_header : typing.Optional[tendermint.types.types_pb2.SignedHeader] = ...,
        validator_set : typing.Optional[tendermint.types.validator_pb2.ValidatorSet] = ...,
        trusted_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        trusted_validators : typing.Optional[tendermint.types.validator_pb2.ValidatorSet] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"signed_header",b"signed_header",u"trusted_height",b"trusted_height",u"trusted_validators",b"trusted_validators",u"validator_set",b"validator_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signed_header",b"signed_header",u"trusted_height",b"trusted_height",u"trusted_validators",b"trusted_validators",u"validator_set",b"validator_set"]) -> None: ...
global___Header = Header

class Fraction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NUMERATOR_FIELD_NUMBER: builtins.int
    DENOMINATOR_FIELD_NUMBER: builtins.int
    numerator: builtins.int = ...
    denominator: builtins.int = ...

    def __init__(self,
        *,
        numerator : builtins.int = ...,
        denominator : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denominator",b"denominator",u"numerator",b"numerator"]) -> None: ...
global___Fraction = Fraction



import pytest
from pyband.obi import *


def test_encode_decode_bool_success():
    # encode
    assert PyObiBool().encode(True) == bytes.fromhex("01")
    assert PyObiBool().encode(False) == bytes.fromhex("00")

    # decode
    assert PyObiBool().decode(bytes.fromhex("01")) == (True, b"")
    assert PyObiBool().decode(bytes.fromhex("00")) == (False, b"")


def test_encode_decode_bool_fail():
    with pytest.raises(ValueError) as e:
        PyObiBool().decode(bytes.fromhex("07"))

    assert str(e.value) == "Boolean value must be 1 or 0 but got 7"


def test_encode_decode_unsigned_integer_success():
    # encode
    assert PyObiInteger("u8").encode(55) == bytes.fromhex("37")
    assert PyObiInteger("u16").encode(55555) == bytes.fromhex("d903")
    assert PyObiInteger("u32").encode(555555555) == bytes.fromhex("211d1ae3")
    assert PyObiInteger("u64").encode(5555555555555555555) == bytes.fromhex("4d194c57dad638e3")
    assert PyObiInteger("u128").encode(55555555555555555555555555555555555555) == bytes.fromhex(
        "29cb9c5d87a03443cc692f78e38e38e3"
    )
    assert PyObiInteger("u256").encode(
        55555555555555555555555555555555555555555555555555555555555555555555555555555
    ) == bytes.fromhex("7ad35483b719950a2913082cd23202dbb41bd2cb9375038e38e38e38e38e38e3")

    # decode
    assert PyObiInteger("u8").decode(bytes.fromhex("37")) == (55, b"")
    assert PyObiInteger("u16").decode(bytes.fromhex("d903")) == (55555, b"")
    assert PyObiInteger("u32").decode(bytes.fromhex("211d1ae3")) == (555555555, b"")
    assert PyObiInteger("u64").decode(bytes.fromhex("4d194c57dad638e3")) == (
        5555555555555555555,
        b"",
    )
    assert PyObiInteger("u128").decode(bytes.fromhex("29cb9c5d87a03443cc692f78e38e38e3")) == (
        55555555555555555555555555555555555555,
        b"",
    )
    assert PyObiInteger("u256").decode(
        bytes.fromhex("7ad35483b719950a2913082cd23202dbb41bd2cb9375038e38e38e38e38e38e3")
    ) == (55555555555555555555555555555555555555555555555555555555555555555555555555555, b"")


def test_encode_decode_unsigned_integer_fail():
    with pytest.raises(OverflowError) as e:
        PyObiInteger("u8").encode(2 ** 8)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("u16").encode(2 ** 16)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("u32").encode(2 ** 32)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("u64").encode(2 ** 64)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("u128").encode(2 ** 128)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("u256").encode(2 ** 256)

    assert str(e.value) == "int too big to convert"


def test_encode_decode_signed_integer():
    # encode
    assert PyObiInteger("i8").encode(42) == bytes.fromhex("2a")
    assert PyObiInteger("i16").encode(42) == bytes.fromhex("002a")
    assert PyObiInteger("i32").encode(42) == bytes.fromhex("0000002a")
    assert PyObiInteger("i64").encode(42) == bytes.fromhex("000000000000002a")
    assert PyObiInteger("i128").encode(42) == bytes.fromhex("0000000000000000000000000000002a")
    assert PyObiInteger("i256").encode(42) == bytes.fromhex(
        "000000000000000000000000000000000000000000000000000000000000002a"
    )

    assert PyObiInteger("i8").encode(-(2 ** 7)) == bytes.fromhex("80")
    assert PyObiInteger("i16").encode(-(2 ** 15)) == bytes.fromhex("8000")
    assert PyObiInteger("i32").encode(-(2 ** 31)) == bytes.fromhex("80000000")
    assert PyObiInteger("i64").encode(-(2 ** 63)) == bytes.fromhex("8000000000000000")
    assert PyObiInteger("i128").encode(-(2 ** 127)) == bytes.fromhex("80000000000000000000000000000000")
    assert PyObiInteger("i256").encode(-(2 ** 255)) == bytes.fromhex(
        "8000000000000000000000000000000000000000000000000000000000000000"
    )

    # decode
    assert PyObiInteger("i8").decode(bytes.fromhex("2a")) == (42, b"")
    assert PyObiInteger("i16").decode(bytes.fromhex("002a")) == (42, b"")
    assert PyObiInteger("i32").decode(bytes.fromhex("0000002a")) == (42, b"")
    assert PyObiInteger("i64").decode(bytes.fromhex("000000000000002a")) == (42, b"")
    assert PyObiInteger("i128").decode(bytes.fromhex("0000000000000000000000000000002a")) == (
        42,
        b"",
    )
    assert PyObiInteger("i256").decode(
        bytes.fromhex("000000000000000000000000000000000000000000000000000000000000002a")
    ) == (42, b"")

    assert PyObiInteger("i8").decode(bytes.fromhex("80")) == (-(2 ** 7), b"")
    assert PyObiInteger("i16").decode(bytes.fromhex("8000")) == (-(2 ** 15), b"")
    assert PyObiInteger("i32").decode(bytes.fromhex("80000000")) == (-(2 ** 31), b"")
    assert PyObiInteger("i64").decode(bytes.fromhex("8000000000000000")) == (-(2 ** 63), b"")
    assert PyObiInteger("i128").decode(bytes.fromhex("80000000000000000000000000000000")) == (
        -(2 ** 127),
        b"",
    )
    assert PyObiInteger("i256").decode(
        bytes.fromhex("8000000000000000000000000000000000000000000000000000000000000000")
    ) == (-(2 ** 255), b"")


def test_encode_decode_signed_integer_fail():
    with pytest.raises(OverflowError) as e:
        PyObiInteger("i8").encode(2 ** 8)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("i16").encode(2 ** 16)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("i32").encode(2 ** 32)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("i64").encode(2 ** 64)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("i128").encode(2 ** 128)

    assert str(e.value) == "int too big to convert"

    with pytest.raises(OverflowError) as e:
        PyObiInteger("i256").encode(2 ** 256)

    assert str(e.value) == "int too big to convert"


def test_encode_decode_str_success():
    # encode
    assert PyObiString().encode("") == bytes.fromhex("00000000")
    assert PyObiString().encode("mumu") == bytes.fromhex("000000046d756d75")

    # decode
    assert PyObiString().decode(bytes.fromhex("00000000")) == ("", b"")
    assert PyObiString().decode(bytes.fromhex("000000046d756d75")) == ("mumu", b"")


def test_encode_decode_bytes():
    # encode
    assert PyObiBytes().encode(bytes([1, 2, 3, 4, 5, 6, 7, 8, 9])) == bytes.fromhex("00000009010203040506070809")

    # decode
    assert PyObiBytes().decode(bytes.fromhex("00000009010203040506070809")) == (
        bytes([1, 2, 3, 4, 5, 6, 7, 8, 9]),
        b"",
    )


def test_encode_decode_array():
    # encode
    # bool
    assert PyObiArray("[bool;0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[bool;1]").encode([False]) == bytes.fromhex("00")
    assert PyObiArray("[bool;5]").encode([True, False, True, False, True]) == bytes.fromhex("0100010001")

    # integer
    assert PyObiArray("[i32;0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[i32;1]").encode([999]) == bytes.fromhex("000003e7")
    assert PyObiArray("[i32;3]").encode([11, 2222, 33333]) == bytes.fromhex("0000000b000008ae00008235")

    # string
    assert PyObiArray("[string;0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[string;1]").encode(["mumu"]) == bytes.fromhex("000000046d756d75")
    assert PyObiArray("[string;3]").encode(["mumu", "lulu", "mumumumu"]) == bytes.fromhex(
        "000000046d756d75000000046c756c75000000086d756d756d756d75"
    )

    # vector
    assert PyObiArray("[[u64];0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[[u64];2]").encode([[1, 2, 3, 4, 5], []]) == bytes.fromhex(
        "000000050000000000000001000000000000000200000000000000030000000000000004000000000000000500000000"
    )
    assert PyObiArray("[[string];3]").encode([["a", "", "b"], [], ["aaa", "bbb"]]) == bytes.fromhex(
        "00000003000000016100000000000000016200000000000000020000000361616100000003626262"
    )

    # bytes
    assert PyObiArray("[bytes;0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[bytes;1]").encode([bytes.fromhex("ababab")]) == bytes.fromhex("00000003ababab")
    assert PyObiArray("[bytes;3]").encode(
        [bytes.fromhex("ababab"), bytes.fromhex("cd"), bytes.fromhex("efef")]
    ) == bytes.fromhex("00000003ababab00000001cd00000002efef")

    # array
    assert PyObiArray("[[bool;2];0]").encode([]) == bytes.fromhex("")
    assert PyObiArray("[[bool;2];3]").encode([[False, False], [True, True], [False, True]]) == bytes.fromhex(
        "000001010001"
    )

    # decode
    # bool
    assert PyObiArray("[bool;0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[bool;1]").decode(bytes.fromhex("00")) == ([False], b"")
    assert PyObiArray("[bool;5]").decode(bytes.fromhex("0100010001")) == (
        [
            True,
            False,
            True,
            False,
            True,
        ],
        b"",
    )

    # integer
    assert PyObiArray("[i32;0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[i32;1]").decode(bytes.fromhex("000003e7")) == ([999], b"")
    assert PyObiArray("[i32;3]").decode(bytes.fromhex("0000000b000008ae00008235")) == (
        [
            11,
            2222,
            33333,
        ],
        b"",
    )

    # string
    assert PyObiArray("[string;0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[string;1]").decode(bytes.fromhex("000000046d756d75")) == (["mumu"], b"")
    assert PyObiArray("[string;3]").decode(
        bytes.fromhex("000000046d756d75000000046c756c75000000086d756d756d756d75")
    ) == (["mumu", "lulu", "mumumumu"], b"")

    # bytes
    assert PyObiArray("[bytes;0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[bytes;1]").decode(bytes.fromhex("00000003ababab")) == (
        [bytes.fromhex("ababab")],
        b"",
    )
    assert PyObiArray("[bytes;3]").decode(bytes.fromhex("00000003ababab00000001cd00000002efef")) == (
        [bytes.fromhex("ababab"), bytes.fromhex("cd"), bytes.fromhex("efef")],
        b"",
    )

    # vector
    assert PyObiArray("[[u64];0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[[u64];2]").decode(
        bytes.fromhex(
            "000000050000000000000001000000000000000200000000000000030000000000000004000000000000000500000000"
        )
    ) == ([[1, 2, 3, 4, 5], []], b"")
    assert PyObiArray("[[string];3]").decode(
        bytes.fromhex("00000003000000016100000000000000016200000000000000020000000361616100000003626262")
    ) == ([["a", "", "b"], [], ["aaa", "bbb"]], b"")

    # array
    assert PyObiArray("[[bool;2];0]").decode(bytes.fromhex("")) == ([], b"")
    assert PyObiArray("[[bool;2];3]").decode(bytes.fromhex("000001010001")) == (
        [
            [False, False],
            [True, True],
            [False, True],
        ],
        b"",
    )


def test_encode_decode_vec():
    # encode
    assert PyObiVector("[i32]").encode([87654321, -12345678]) == bytes.fromhex("0000000205397fb1ff439eb2")
    assert PyObiVector("[string]").encode(["mumu", "imprefvicticious"]) == bytes.fromhex(
        "00000002000000046d756d7500000010696d70726566766963746963696f7573"
    )

    # decode
    assert PyObiVector("[i32]").decode(bytes.fromhex("0000000205397fb1ff439eb2")) == (
        [87654321, -12345678],
        b"",
    )
    assert PyObiVector("[string]").decode(
        bytes.fromhex("00000002000000046d756d7500000010696d70726566766963746963696f7573")
    ) == (["mumu", "imprefvicticious"], b"")


def test_encode_decode_struct():
    # encode
    assert PyObiStruct("""{symbol:string,px:u64}""").encode({"symbol": "BTC", "px": 7777777777777777777}).hex() == (
        "000000034254436bf037ae325f1c71"
    )

    # decode
    assert PyObiStruct("""{symbol:string,px:u64}""").decode(bytes.fromhex("000000034254436bf037ae325f1c71")) == (
        {"symbol": "BTC", "px": 7777777777777777777},
        b"",
    )


def test_decode_multi_obis():
    # BTC, 50, 100
    data = bytes.fromhex("00000003425443000000000000003264")
    symbol, remaining = PyObiString().decode(data)
    x, remaining = PyObiInteger("u64").decode(remaining)
    y, remaining = PyObiInteger("u8").decode(remaining)
    assert ["BTC", 50, 100] == [symbol, x, y]

    # band, 400, 100
    data = bytes.fromhex("0000000462616e64000000000000019064")
    symbol, remaining = PyObiString().decode(data)
    x, remaining = PyObiInteger("u64").decode(remaining)
    y, remaining = PyObiInteger("u8").decode(remaining)
    assert ["band", 400, 100] == [symbol, x, y]


def test_encode_decode_single_success():
    obi = PyObi(
        """
        {
            symbol: string,
            px: u64,
            in: {
                a: u8,
                b: u16,
                in_in: {
                    c:bool,
                    d:bytes
                },
                e: u32
            },
            tb:bool
        }
        """
    )
    test_struct = {
        "symbol": "BTC",
        "px": 9000,
        "in": {
            "a": 1,
            "b": 2,
            "in_in": {"c": True, "d": bytes.fromhex("00112233445566778899")},
            "e": 999999,
        },
        "tb": False,
    }

    encoded = obi.encode(test_struct)
    assert "000000034254430000000000002328010002010000000a00112233445566778899000f423f00" == encoded.hex()
    assert test_struct == obi.decode(encoded)


def test_encode_decode_input_output():
    obi = PyObi("{symbol: string,px: u64,in: {a: u8,b: u8}, tb:bool} / string")
    test_input = {"symbol": "BTC", "px": 9000, "in": {"a": 1, "b": 2}, "tb": False}

    encoded = obi.encode_input(test_input)
    assert "000000034254430000000000002328010200" == encoded.hex()
    assert test_input == obi.decode_input(encoded)

    test_output = "mumumumu"
    encoded = obi.encode_output(test_output)
    assert "000000086d756d756d756d75" == encoded.hex()
    assert test_output == obi.decode_output(encoded)


def test_encode_decode_muti():
    obi = PyObi(
        """
        {
            symbol: string,
            px: u64,
            in: {
                a: u8,
                b: u16,
                in_in: {
                    c:bool,
                    d:bytes
                },
                e: u32
            },
            tb:bool
        }
        /
        string
        /
        u256
        /
        [[u32]]
        /
        {
            a: [
                {
                    a1: [i8],
                    a2: bytes
                }
            ],
            b: {
                b1: [bool]
            },
            c: [string]
        }
        /
        [[u64];10]
        /
        [
            {
                a: [string;2],
                b: u8
            }
            ;3
        ]
        """
    )

    test_structs = [
        {
            "symbol": "BTC",
            "px": 9000,
            "in": {
                "a": 1,
                "b": 2,
                "in_in": {"c": True, "d": bytes.fromhex("00112233445566778899")},
                "e": 999999,
            },
            "tb": False,
        },
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.",
        11142281140674468977901077842737737931203453356601189394763448166092322549068,
        [[1, 2, 3], [44, 55, 66, 77, 88], [9999, 10000, 10001, 10002, 10003], [12345678], []],
        {
            "a": [
                {"a1": [-1, -2, -3, 0, 1, 2, 3], "a2": bytes.fromhex("abcdef")},
                {"a1": [100], "a2": bytes.fromhex("0" * 10)},
                {"a1": [], "a2": bytes.fromhex("a" * 128)},
            ],
            "b": {"b1": [True, False, True, True, True, True, False]},
            "c": ["mumu", "lulu", "momo", "toto", "coco", "bobo"],
        },
        [[], [1], [2, 22], [3, 33, 333], [4], [5], [6, 66], [7, 7777], [8], [9]],
        [{"a": ["a1", "a2"], "b": 15}, {"a": ["a3", "a4"], "b": 68}, {"a": ["a5", "a6"], "b": 200}],
    ]

    # struct 1
    encoded = obi.encode(test_structs[0], 0)
    assert "000000034254430000000000002328010002010000000a00112233445566778899000f423f00" == encoded.hex()
    assert test_structs[0] == obi.decode(encoded, 0)

    # struct 2
    encoded = obi.encode(test_structs[1], 1)
    assert (
        "000001bd4c6f72656d20697073756d20646f6c6f722073697420616d65742c20636f6e73656374657475722061646970697363696e6720656c69742c2073656420646f20656975736d6f642074656d706f7220696e6369646964756e74207574206c61626f726520657420646f6c6f7265206d61676e6120616c697175612e20557420656e696d206164206d696e696d2076656e69616d2c2071756973206e6f737472756420657865726369746174696f6e20756c6c616d636f206c61626f726973206e69736920757420616c697175697020657820656120636f6d6d6f646f20636f6e7365717561742e2044756973206175746520697275726520646f6c6f7220696e20726570726568656e646572697420696e20766f6c7570746174652076656c697420657373652063696c6c756d20646f6c6f726520657520667567696174206e756c6c612070617269617475722e204578636570746575722073696e74206f6363616563617420637570696461746174206e6f6e2070726f6964656e742c2073756e7420696e2063756c706120717569206f666669636961206465736572756e74206d6f6c6c697420616e696d20696420657374206c61626f72756d2e"
        == encoded.hex()
    )
    assert test_structs[1] == obi.decode(encoded, 1)

    # struct 3
    encoded = obi.encode(test_structs[2], 2)
    assert "18a24ec1659380f421195719845bbff4df8568c7bd615812b39436bbcb8ead4c" == encoded.hex()
    assert test_structs[2] == obi.decode(encoded, 2)

    # struct 4
    encoded = obi.encode(test_structs[3], 3)
    assert (
        "0000000500000003000000010000000200000003000000050000002c00000037000000420000004d00000058000000050000270f000027100000271100002712000027130000000100bc614e00000000"
        == encoded.hex()
    )
    assert test_structs[3] == obi.decode(encoded, 3)

    # struct 5
    encoded = obi.encode(test_structs[4], 4)
    assert (
        "0000000300000007fffefd0001020300000003abcdef00000001640000000500000000000000000000000040aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa000000070100010101010000000006000000046d756d75000000046c756c75000000046d6f6d6f00000004746f746f00000004636f636f00000004626f626f"
        == encoded.hex()
    )
    assert test_structs[4] == obi.decode(encoded, 4)

    # struct 6
    encoded = obi.encode(test_structs[5], 5)
    assert (
        "0000000000000001000000000000000100000002000000000000000200000000000000160000000300000000000000030000000000000021000000000000014d00000001000000000000000400000001000000000000000500000002000000000000000600000000000000420000000200000000000000070000000000001e61000000010000000000000008000000010000000000000009"
        == encoded.hex()
    )
    assert test_structs[5] == obi.decode(encoded, 5)

    # struct 7
    encoded = obi.encode(test_structs[6], 6)
    assert "0000000261310000000261320f00000002613300000002613444000000026135000000026136c8" == encoded.hex()
    assert test_structs[6] == obi.decode(encoded, 6)


def test_encode_decode_not_all_data_is_consumed_fail():
    with pytest.raises(DecodeError) as e:
        PyObi("""bool""").decode(bytes.fromhex("00aa"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""i64""").decode(bytes.fromhex("00112233445566778899"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""u64""").decode(bytes.fromhex("00112233445566778899"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""string""").decode(bytes.fromhex("00000000aabb"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""bytes""").decode(bytes.fromhex("00000000aabb"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""[u32]""").decode(bytes.fromhex("00000000aabb"))

    assert str(e.value) == "Not all data is consumed after decoding input"

    with pytest.raises(DecodeError) as e:
        PyObi("""{ x:i16 }""").decode(bytes.fromhex("00000000"))

    assert str(e.value) == "Not all data is consumed after decoding input"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ConsensusParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int

    @property
    def block(self) -> global___BlockParams: ...

    @property
    def evidence(self) -> global___EvidenceParams: ...

    @property
    def validator(self) -> global___ValidatorParams: ...

    @property
    def version(self) -> global___VersionParams: ...

    def __init__(self,
        *,
        block : typing.Optional[global___BlockParams] = ...,
        evidence : typing.Optional[global___EvidenceParams] = ...,
        validator : typing.Optional[global___ValidatorParams] = ...,
        version : typing.Optional[global___VersionParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> None: ...
global___ConsensusParams = ConsensusParams

class BlockParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_BYTES_FIELD_NUMBER: builtins.int
    MAX_GAS_FIELD_NUMBER: builtins.int
    TIME_IOTA_MS_FIELD_NUMBER: builtins.int
    max_bytes: builtins.int = ...
    max_gas: builtins.int = ...
    time_iota_ms: builtins.int = ...

    def __init__(self,
        *,
        max_bytes : builtins.int = ...,
        max_gas : builtins.int = ...,
        time_iota_ms : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_bytes",b"max_bytes",u"max_gas",b"max_gas",u"time_iota_ms",b"time_iota_ms"]) -> None: ...
global___BlockParams = BlockParams

class EvidenceParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: builtins.int
    MAX_AGE_DURATION_FIELD_NUMBER: builtins.int
    MAX_BYTES_FIELD_NUMBER: builtins.int
    max_age_num_blocks: builtins.int = ...
    max_bytes: builtins.int = ...

    @property
    def max_age_duration(self) -> google.protobuf.duration_pb2.Duration: ...

    def __init__(self,
        *,
        max_age_num_blocks : builtins.int = ...,
        max_age_duration : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        max_bytes : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"max_age_duration",b"max_age_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_age_duration",b"max_age_duration",u"max_age_num_blocks",b"max_age_num_blocks",u"max_bytes",b"max_bytes"]) -> None: ...
global___EvidenceParams = EvidenceParams

class ValidatorParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUB_KEY_TYPES_FIELD_NUMBER: builtins.int

    @property
    def pub_key_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        pub_key_types : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pub_key_types",b"pub_key_types"]) -> None: ...
global___ValidatorParams = ValidatorParams

class VersionParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_VERSION_FIELD_NUMBER: builtins.int
    app_version: builtins.int = ...

    def __init__(self,
        *,
        app_version : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_version",b"app_version"]) -> None: ...
global___VersionParams = VersionParams

class HashedParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_MAX_BYTES_FIELD_NUMBER: builtins.int
    BLOCK_MAX_GAS_FIELD_NUMBER: builtins.int
    block_max_bytes: builtins.int = ...
    block_max_gas: builtins.int = ...

    def __init__(self,
        *,
        block_max_bytes : builtins.int = ...,
        block_max_gas : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_max_bytes",b"block_max_bytes",u"block_max_gas",b"block_max_gas"]) -> None: ...
global___HashedParams = HashedParams



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from oracle.v1 import oracle_pb2 as oracle_dot_v1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracle/v1/genesis.proto',
  package='oracle.v1',
  syntax='proto3',
  serialized_options=b'Z,github.com/bandprotocol/chain/x/oracle/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17oracle/v1/genesis.proto\x12\toracle.v1\x1a\x14gogoproto/gogo.proto\x1a\x16oracle/v1/oracle.proto\"\xdc\x01\n\x0cGenesisState\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x11.oracle.v1.ParamsB\x04\xc8\xde\x1f\x00\x12\x31\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x15.oracle.v1.DataSourceB\x04\xc8\xde\x1f\x00\x12\x35\n\x0eoracle_scripts\x18\x03 \x03(\x0b\x32\x17.oracle.v1.OracleScriptB\x04\xc8\xde\x1f\x00\x12\x39\n\treporters\x18\x04 \x03(\x0b\x32 .oracle.v1.ReportersPerValidatorB\x04\xc8\xde\x1f\x00\x42.Z,github.com/bandprotocol/chain/x/oracle/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,oracle_dot_v1_dot_oracle__pb2.DESCRIPTOR,])




_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='oracle.v1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='oracle.v1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_sources', full_name='oracle.v1.GenesisState.data_sources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scripts', full_name='oracle.v1.GenesisState.oracle_scripts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporters', full_name='oracle.v1.GenesisState.reporters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=305,
)

_GENESISSTATE.fields_by_name['params'].message_type = oracle_dot_v1_dot_oracle__pb2._PARAMS
_GENESISSTATE.fields_by_name['data_sources'].message_type = oracle_dot_v1_dot_oracle__pb2._DATASOURCE
_GENESISSTATE.fields_by_name['oracle_scripts'].message_type = oracle_dot_v1_dot_oracle__pb2._ORACLESCRIPT
_GENESISSTATE.fields_by_name['reporters'].message_type = oracle_dot_v1_dot_oracle__pb2._REPORTERSPERVALIDATOR
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'oracle.v1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:oracle.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_GENESISSTATE.fields_by_name['params']._options = None
_GENESISSTATE.fields_by_name['data_sources']._options = None
_GENESISSTATE.fields_by_name['oracle_scripts']._options = None
_GENESISSTATE.fields_by_name['reporters']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from oracle.v1 import query_pb2 as oracle_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Counts = channel.unary_unary(
                '/oracle.v1.Query/Counts',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryCountsRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryCountsResponse.FromString,
                )
        self.Data = channel.unary_unary(
                '/oracle.v1.Query/Data',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryDataRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryDataResponse.FromString,
                )
        self.DataSource = channel.unary_unary(
                '/oracle.v1.Query/DataSource',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryDataSourceRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryDataSourceResponse.FromString,
                )
        self.OracleScript = channel.unary_unary(
                '/oracle.v1.Query/OracleScript',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryOracleScriptRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryOracleScriptResponse.FromString,
                )
        self.Request = channel.unary_unary(
                '/oracle.v1.Query/Request',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestResponse.FromString,
                )
        self.PendingRequests = channel.unary_unary(
                '/oracle.v1.Query/PendingRequests',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryPendingRequestsRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryPendingRequestsResponse.FromString,
                )
        self.Validator = channel.unary_unary(
                '/oracle.v1.Query/Validator',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryValidatorRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryValidatorResponse.FromString,
                )
        self.Reporters = channel.unary_unary(
                '/oracle.v1.Query/Reporters',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryReportersRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryReportersResponse.FromString,
                )
        self.ActiveValidators = channel.unary_unary(
                '/oracle.v1.Query/ActiveValidators',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/oracle.v1.Query/Params',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.RequestSearch = channel.unary_unary(
                '/oracle.v1.Query/RequestSearch',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestSearchRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestSearchResponse.FromString,
                )
        self.RequestPrice = channel.unary_unary(
                '/oracle.v1.Query/RequestPrice',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestPriceRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestPriceResponse.FromString,
                )
        self.RequestVerification = channel.unary_unary(
                '/oracle.v1.Query/RequestVerification',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestVerificationRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestVerificationResponse.FromString,
                )
        self.RequestPool = channel.unary_unary(
                '/oracle.v1.Query/RequestPool',
                request_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestPoolRequest.SerializeToString,
                response_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestPoolResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Counts(self, request, context):
        """Counts queries the number of existing data sources, oracle scripts, and
        requests.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Data(self, request, context):
        """Data queries content of the data source or oracle script for given SHA256
        file hash.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DataSource(self, request, context):
        """DataSource queries data source summary info for given data source id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OracleScript(self, request, context):
        """OracleScript queries oracle script summary info for given oracle script id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Request(self, request, context):
        """Request queries request info for given request id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PendingRequests(self, request, context):
        """PendingRequests queries list of pending request IDs assigned to given
        validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Validator(self, request, context):
        """Validator queries properties of given validator address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reporters(self, request, context):
        """Reporters queries all reporters associated with given validator address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActiveValidators(self, request, context):
        """ActiveValidators queries all active oracle validators.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries parameters used for runnning bandchain network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestSearch(self, request, context):
        """RequestSearch queries the latest request that match search criteria.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestPrice(self, request, context):
        """RequestPrice queries the latest price on standard price reference oracle
        script.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestVerification(self, request, context):
        """RequestVerification verifies a request to make sure that
        all information that will be used to report the data is valid
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RequestPool(self, request, context):
        """RequestPool queries the request pool information corresponding to the given
        port, channel, and request key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Counts': grpc.unary_unary_rpc_method_handler(
                    servicer.Counts,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryCountsRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryCountsResponse.SerializeToString,
            ),
            'Data': grpc.unary_unary_rpc_method_handler(
                    servicer.Data,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryDataRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryDataResponse.SerializeToString,
            ),
            'DataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.DataSource,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryDataSourceRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryDataSourceResponse.SerializeToString,
            ),
            'OracleScript': grpc.unary_unary_rpc_method_handler(
                    servicer.OracleScript,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryOracleScriptRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryOracleScriptResponse.SerializeToString,
            ),
            'Request': grpc.unary_unary_rpc_method_handler(
                    servicer.Request,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestResponse.SerializeToString,
            ),
            'PendingRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.PendingRequests,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryPendingRequestsRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryPendingRequestsResponse.SerializeToString,
            ),
            'Validator': grpc.unary_unary_rpc_method_handler(
                    servicer.Validator,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryValidatorRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryValidatorResponse.SerializeToString,
            ),
            'Reporters': grpc.unary_unary_rpc_method_handler(
                    servicer.Reporters,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryReportersRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryReportersResponse.SerializeToString,
            ),
            'ActiveValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.ActiveValidators,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'RequestSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestSearch,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestSearchRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestSearchResponse.SerializeToString,
            ),
            'RequestPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestPrice,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestPriceRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestPriceResponse.SerializeToString,
            ),
            'RequestVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestVerification,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestVerificationRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestVerificationResponse.SerializeToString,
            ),
            'RequestPool': grpc.unary_unary_rpc_method_handler(
                    servicer.RequestPool,
                    request_deserializer=oracle_dot_v1_dot_query__pb2.QueryRequestPoolRequest.FromString,
                    response_serializer=oracle_dot_v1_dot_query__pb2.QueryRequestPoolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oracle.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Counts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Counts',
            oracle_dot_v1_dot_query__pb2.QueryCountsRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryCountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Data(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Data',
            oracle_dot_v1_dot_query__pb2.QueryDataRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/DataSource',
            oracle_dot_v1_dot_query__pb2.QueryDataSourceRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OracleScript(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/OracleScript',
            oracle_dot_v1_dot_query__pb2.QueryOracleScriptRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryOracleScriptResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Request(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Request',
            oracle_dot_v1_dot_query__pb2.QueryRequestRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PendingRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/PendingRequests',
            oracle_dot_v1_dot_query__pb2.QueryPendingRequestsRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryPendingRequestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Validator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Validator',
            oracle_dot_v1_dot_query__pb2.QueryValidatorRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryValidatorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reporters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Reporters',
            oracle_dot_v1_dot_query__pb2.QueryReportersRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryReportersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActiveValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/ActiveValidators',
            oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryActiveValidatorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/Params',
            oracle_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/RequestSearch',
            oracle_dot_v1_dot_query__pb2.QueryRequestSearchRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryRequestSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/RequestPrice',
            oracle_dot_v1_dot_query__pb2.QueryRequestPriceRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryRequestPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/RequestVerification',
            oracle_dot_v1_dot_query__pb2.QueryRequestVerificationRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryRequestVerificationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RequestPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/oracle.v1.Query/RequestPool',
            oracle_dot_v1_dot_query__pb2.QueryRequestPoolRequest.SerializeToString,
            oracle_dot_v1_dot_query__pb2.QueryRequestPoolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FungibleTokenPacketData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    RECEIVER_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...
    amount: builtins.int = ...
    sender: typing.Text = ...
    receiver: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        amount : builtins.int = ...,
        sender : typing.Text = ...,
        receiver : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"denom",b"denom",u"receiver",b"receiver",u"sender",b"sender"]) -> None: ...
global___FungibleTokenPacketData = FungibleTokenPacketData

class DenomTrace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    BASE_DENOM_FIELD_NUMBER: builtins.int
    path: typing.Text = ...
    base_denom: typing.Text = ...

    def __init__(self,
        *,
        path : typing.Text = ...,
        base_denom : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_denom",b"base_denom",u"path",b"path"]) -> None: ...
global___DenomTrace = DenomTrace

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEND_ENABLED_FIELD_NUMBER: builtins.int
    RECEIVE_ENABLED_FIELD_NUMBER: builtins.int
    send_enabled: builtins.bool = ...
    receive_enabled: builtins.bool = ...

    def __init__(self,
        *,
        send_enabled : builtins.bool = ...,
        receive_enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"receive_enabled",b"receive_enabled",u"send_enabled",b"send_enabled"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    DENOM_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    denom: typing.Text = ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        denom : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"denom",b"denom"]) -> None: ...
global___QueryBalanceRequest = QueryBalanceRequest

class QueryBalanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BALANCE_FIELD_NUMBER: builtins.int

    @property
    def balance(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        balance : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"balance",b"balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"balance",b"balance"]) -> None: ...
global___QueryBalanceResponse = QueryBalanceResponse

class QueryAllBalancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"pagination",b"pagination"]) -> None: ...
global___QueryAllBalancesRequest = QueryAllBalancesRequest

class QueryAllBalancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BALANCES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        balances : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"balances",b"balances",u"pagination",b"pagination"]) -> None: ...
global___QueryAllBalancesResponse = QueryAllBalancesResponse

class QueryTotalSupplyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryTotalSupplyRequest = QueryTotalSupplyRequest

class QueryTotalSupplyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUPPLY_FIELD_NUMBER: builtins.int

    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        supply : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"supply",b"supply"]) -> None: ...
global___QueryTotalSupplyResponse = QueryTotalSupplyResponse

class QuerySupplyOfRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom",b"denom"]) -> None: ...
global___QuerySupplyOfRequest = QuerySupplyOfRequest

class QuerySupplyOfResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AMOUNT_FIELD_NUMBER: builtins.int

    @property
    def amount(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...

    def __init__(self,
        *,
        amount : typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"amount",b"amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount"]) -> None: ...
global___QuerySupplyOfResponse = QuerySupplyOfResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.bank.v1beta1.bank_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryDenomsMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryDenomsMetadataRequest = QueryDenomsMetadataRequest

class QueryDenomsMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    METADATAS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def metadatas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        metadatas : typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"metadatas",b"metadatas",u"pagination",b"pagination"]) -> None: ...
global___QueryDenomsMetadataResponse = QueryDenomsMetadataResponse

class QueryDenomMetadataRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_FIELD_NUMBER: builtins.int
    denom: typing.Text = ...

    def __init__(self,
        *,
        denom : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom",b"denom"]) -> None: ...
global___QueryDenomMetadataRequest = QueryDenomMetadataRequest

class QueryDenomMetadataResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    METADATA_FIELD_NUMBER: builtins.int

    @property
    def metadata(self) -> cosmos.bank.v1beta1.bank_pb2.Metadata: ...

    def __init__(self,
        *,
        metadata : typing.Optional[cosmos.bank.v1beta1.bank_pb2.Metadata] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> None: ...
global___QueryDenomMetadataResponse = QueryDenomMetadataResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgCreateClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    signer: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state",u"signer",b"signer"]) -> None: ...
global___MsgCreateClient = MsgCreateClient

class MsgCreateClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgCreateClientResponse = MsgCreateClientResponse

class MsgUpdateClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    signer: typing.Text = ...

    @property
    def header(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        header : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"header",b"header",u"signer",b"signer"]) -> None: ...
global___MsgUpdateClient = MsgUpdateClient

class MsgUpdateClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgUpdateClientResponse = MsgUpdateClientResponse

class MsgUpgradeClient(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_STATE_FIELD_NUMBER: builtins.int
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    PROOF_UPGRADE_CLIENT_FIELD_NUMBER: builtins.int
    PROOF_UPGRADE_CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    proof_upgrade_client: builtins.bytes = ...
    proof_upgrade_consensus_state: builtins.bytes = ...
    signer: typing.Text = ...

    @property
    def client_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        client_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        proof_upgrade_client : builtins.bytes = ...,
        proof_upgrade_consensus_state : builtins.bytes = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"client_state",b"client_state",u"consensus_state",b"consensus_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"client_state",b"client_state",u"consensus_state",b"consensus_state",u"proof_upgrade_client",b"proof_upgrade_client",u"proof_upgrade_consensus_state",b"proof_upgrade_consensus_state",u"signer",b"signer"]) -> None: ...
global___MsgUpgradeClient = MsgUpgradeClient

class MsgUpgradeClientResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgUpgradeClientResponse = MsgUpgradeClientResponse

class MsgSubmitMisbehaviour(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    MISBEHAVIOUR_FIELD_NUMBER: builtins.int
    SIGNER_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    signer: typing.Text = ...

    @property
    def misbehaviour(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        misbehaviour : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        signer : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"misbehaviour",b"misbehaviour"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"misbehaviour",b"misbehaviour",u"signer",b"signer"]) -> None: ...
global___MsgSubmitMisbehaviour = MsgSubmitMisbehaviour

class MsgSubmitMisbehaviourResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgSubmitMisbehaviourResponse = MsgSubmitMisbehaviourResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.params.v1beta1.params_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    subspace: typing.Text = ...
    key: typing.Text = ...

    def __init__(self,
        *,
        subspace : typing.Text = ...,
        key : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"subspace",b"subspace"]) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAM_FIELD_NUMBER: builtins.int

    @property
    def param(self) -> cosmos.params.v1beta1.params_pb2.ParamChange: ...

    def __init__(self,
        *,
        param : typing.Optional[cosmos.params.v1beta1.params_pb2.ParamChange] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"param",b"param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"param",b"param"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse
